selectionplot: Select Optimal Three-Tree Combination

View source: R/longitree.R

selectionplotR Documentation

Select Optimal Three-Tree Combination

Description

Plots the cross-validated prediction error against the maximum pairwise adjusted Rand index (ARI) for candidate three-tree subsets, and selects a subset based on either prediction performance or tree diversification. The selected combination is indicated by a red point on the plot, which corresponds to the three trees used in the subsequent threetrees step.

Usage

selectionplot(longitrees, metric, nth)

Arguments

longitrees

A longitrees object.

metric

"PE" to select the subset with the smallest cross-validated prediction error, or "ARI" to select the subset with the smallest maximum pairwise ARI (greatest tree diversification).

nth

Rank of the tree subset to select (1 = best).

Value

An object of class "selectionplot". Pass to threetrees to refit and evaluate the selected trees.

References

Obata, R. and Sugimoto, T. (2026). A decision tree analysis for longitudinal measurement data and its applications. Advances in Data Analysis and Classification. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11634-025-00665-2")}

See Also

longitrees, threetrees


longitree documentation built on May 16, 2026, 5:06 p.m.