| selectionplot | R Documentation |
Plots the cross-validated prediction error against the maximum pairwise
adjusted Rand index (ARI) for candidate three-tree subsets, and selects
a subset based on either prediction performance or tree diversification.
The selected combination is indicated by a red point on the plot, which
corresponds to the three trees used in the subsequent
threetrees step.
selectionplot(longitrees, metric, nth)
longitrees |
A |
metric |
|
nth |
Rank of the tree subset to select (1 = best). |
An object of class "selectionplot". Pass to
threetrees to refit and evaluate the selected trees.
Obata, R. and Sugimoto, T. (2026). A decision tree analysis for longitudinal measurement data and its applications. Advances in Data Analysis and Classification. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11634-025-00665-2")}
longitrees, threetrees
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.